Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
var Rules;
(function (Rules) {
    Rules.SCOPED_COMMIT_REGEXP = /[a-z]+[\s]?\(.+\):/;
    function noUnscoped(text) {
        return {
            failed: !Rules.SCOPED_COMMIT_REGEXP.test(text),
            message: "Unscoped commit messages are not allowed."
        };
    }
    Rules.noUnscoped = noUnscoped;
    function maxLength(text, part, maxLength) {
        return {
            failed: maxLength < text.length,
            message: `Commit '${part}' cannot exceed ${maxLength} characters.`
        };
    }
    Rules.maxLength = maxLength;
    function validTypes(text, part, validTypes) {
        return {
            failed: !new RegExp(`^(${validTypes.join("|")})$`).test(text),
            message: `Commit '${part}' is not valid. Valid types are: ${validTypes.join(", ")}.`
        };
    }
    Rules.validTypes = validTypes;
    function noDash(text, part) {
        return {
            failed: text.indexOf("-") > -1,
            message: `Commit '${part}' cannot contain dashes.`
        };
    }
    Rules.noDash = noDash;
    function noSpace(text, part) {
        return {
            failed: text.indexOf(" ") > -1,
            message: `Commit '${part}' cannot contain spaces.`
        };
    }
    Rules.noSpace = noSpace;
    function noUnderscore(text, part) {
        return {
            failed: text.indexOf("_") > -1,
            message: `Commit '${part}' cannot contain underscore.`
        };
    }
    Rules.noUnderscore = noUnderscore;
    function noCamelCase(text, part) {
        return {
            failed: _.camelCase(text) === text,
            message: `Commit '${part}' cannot be in CamelCase format.`
        };
    }
    Rules.noCamelCase = noCamelCase;
    function noKebabCase(text, part) {
        return {
            failed: _.kebabCase(text) === text,
            message: `Commit '${part}' cannot be in KebabCase format.`
        };
    }
    Rules.noKebabCase = noKebabCase;
    function noUpperFirst(text, part) {
        return {
            failed: /^[A-Z]/.test(text),
            message: `Commit '${part}' first character cannot be UpperCase.`
        };
    }
    Rules.noUpperFirst = noUpperFirst;
    function noLowerFirst(text, part) {
        return {
            failed: /^[a-z]/.test(text),
            message: `Commit '${part}' first character cannot be in LowerCase.`
        };
    }
    Rules.noLowerFirst = noLowerFirst;
    function noPeriodAtEnd(text, part) {
        return {
            failed: /[.]$/.test(text),
            message: `Commit '${part}' last character cannot be a period.`
        };
    }
    Rules.noPeriodAtEnd = noPeriodAtEnd;
})(Rules = exports.Rules || (exports.Rules = {}));
