var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const fs_1 = require("fs");
const path_1 = require("path");
let _rootPath;
function getRootPath() {
    if (!_.isNil(_rootPath)) {
        return _rootPath;
    }
    _rootPath = findFileRecursively();
    if (!_rootPath) {
        _rootPath = "";
    }
    return _rootPath;
}
exports.getRootPath = getRootPath;
function readFileAsync(path) {
    return new Promise((resolve, reject) => {
        fs_1.readFile(path, "utf-8", (error, data) => {
            if (error) {
                return reject(error);
            }
            return resolve(data);
        });
    });
}
exports.readFileAsync = readFileAsync;
function readJsonFileAsync(path) {
    return __awaiter(this, void 0, void 0, function* () {
        return JSON.parse(yield readFileAsync(path));
    });
}
exports.readJsonFileAsync = readJsonFileAsync;
function getCommitMessage() {
    return __awaiter(this, void 0, void 0, function* () {
        const result = yield readFileAsync(process.argv[2]);
        if (!result) {
            throw new Error("No commit message provided.");
        }
        return result.split("\n", 1)[0];
    });
}
exports.getCommitMessage = getCommitMessage;
/**
 * Find a file recursively in the file system from the starting path upwards.
 *
 * Defaults: fileName: package.json, startPath: process.cwd()
 *
 * @export
 * @param {string} [path="package.json"]
 * @param {string} [startPath=process.cwd()]
 * @returns {(string | null)}
 */
function findFileRecursively(path = "package.json", startPath = process.cwd()) {
    startPath = path_1.normalize(startPath);
    try {
        const directory = path_1.join(startPath, path_1.sep);
        fs_1.statSync(path_1.join(directory, path));
        return directory;
    }
    catch (error) {
        // do nothing
    }
    let position = _.lastIndexOf(startPath, path_1.sep);
    if (position < 0) {
        return null;
    }
    const truncatedPath = startPath.substr(0, position++);
    return findFileRecursively(path, truncatedPath);
}
exports.findFileRecursively = findFileRecursively;
