var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const utils_1 = require("../utils");
const rules_1 = require("../rules");
const config_1 = require("../config");
var Validator;
(function (Validator) {
    function validate(commitMessage, configFilePath) {
        return __awaiter(this, void 0, void 0, function* () {
            commitMessage = commitMessage || (yield utils_1.getCommitMessage());
            const config = yield config_1.getConfig(config_1.getConfigFilePath(configFilePath || "speedy-commit-msg.json"));
            const { type, message, scope, subject } = config.rules;
            if (message) {
                validatePart(commitMessage, rules_1.COMMIT_MESSAGE_PART.Message, message);
            }
            if (!rules_1.Rules.SCOPED_COMMIT_REGEXP.test(commitMessage)) {
                return;
            }
            const msgSplit = /(.+)\((.+)\):\s{1}(.+)/.exec(commitMessage);
            if (!msgSplit) {
                throw new Error(`Commit message 'header' must be in this format: '<type>(<scope>): <subject>'`);
            }
            const [, msgType, msgScope, msgSubject] = msgSplit;
            if (msgType) {
                validatePart(msgType, rules_1.COMMIT_MESSAGE_PART.Type, type);
            }
            if (msgScope) {
                validatePart(msgScope, rules_1.COMMIT_MESSAGE_PART.Scope, scope);
            }
            if (msgSubject) {
                validatePart(msgSubject, rules_1.COMMIT_MESSAGE_PART.Subject, subject);
            }
        });
    }
    Validator.validate = validate;
    function validatePart(text, messagePart, options) {
        _.forEach(options, (value, key) => {
            if (value === false) {
                return;
            }
            const result = _.get(rules_1.Rules, _.camelCase(key))
                .call(null, text, messagePart, value);
            if (result.failed) {
                throw new Error(result.message);
            }
        });
    }
    Validator.validatePart = validatePart;
})(Validator = exports.Validator || (exports.Validator = {}));
